@@ -60,3 +60,7 @@ def main():
 
     if not args.no_wait:
         run.wait_for_completion()
+
+
+if __name__ == '__main__':
+    main()
